==> access_unpublished-8.x-1.8.zip: access_unpublished/src/Form/AccessUnpublishedForm.php <==
<?php

namespace Drupal\access_unpublished\Form;

use Drupal\access_unpublished\AccessUnpublished;
use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\ReplaceCommand;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Entity\EntityForm;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Alter the entity form to add access unpublished elements.
 */
class AccessUnpublishedForm implements ContainerInjectionInterface {

  use StringTranslationTrait;

  /**
   * Entity type manager service.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Access unpublished config.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $config;

  /**
   * AccessUnpublishedForm constructor.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   Entity type manager service.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   Config factory service.
   */
  public function __construct(EntityTypeManagerInterface $entityTypeManager, ConfigFactoryInterface $configFactory) {
    $this->entityTypeManager = $entityTypeManager;
    $this->config = $configFactory->get('access_unpublished.settings');
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager'),
      $container->get('config.factory')
    );
  }

  /**
   * Alter the entity form to add access unpublished elements.
   */
  public function formAlter(&$form, FormStateInterface $form_state) {
    $form_object = $form_state->getFormObject();
    if (!$form_object instanceof EntityForm) {
      return;
    }

    // Determines if the given form operation is add or edit. Prevents the
    // access unpublished form from being displayed on other random entity
    // forms, for example, the delete form.
    if (!in_array($form_object->getOperation(), ['edit', 'default'], TRUE)) {
      return;
    }

    /** @var \Drupal\Core\Entity\EntityInterface $entity */
    $entity = $form_object->getEntity();

    if (AccessUnpublished::applicableEntityType($entity->getEntityType()) && !$entity->isPublished() && !$entity->isNew()) {

      /** @var \Drupal\Core\Entity\EntityListBuilder $list_builder */
      $list_builder = $this->entityTypeManager->getHandler('access_token', 'entity_form_list_builder');

      $form['access_unpublished_settings'] = [
        '#type' => 'details',
        '#title' => $this->t('Temporary unpublished access'),
        '#weight' => 35,
        '#attributes' => [
          'class' => ['access-unpublished-form'],
          'id' => 'edit-access-unpublished-settings',
        ],
        '#optional' => FALSE,
        '#group' => 'advanced',
      ];

      $form['access_unpublished_settings'] += $list_builder->render($entity);

      $form['access_unpublished_settings']['duration'] = [
        '#type' => 'select',
        '#title' => $this->t('Lifetime'),
        '#options' => static::getDurationOptions(),
        '#default_value' => $this->config->get('duration'),
        '#attributes' => [
          'id' => 'edit-duration',
        ],
      ];

      $form['access_unpublished_settings']['generate_token'] = [
        '#type' => 'button',
        '#value' => $this->t('Generate token'),
        '#ajax' => [
          'callback' => [__CLASS__, 'generateToken'],
        ],
        '#attributes' => [
          'id' => 'edit-generate-token',
        ],
      ];
    }
  }

  /**
   * Submit callback to generate a token.
   *
   * @param array $form
   *   Form array.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The form state.
   *
   * @return \Drupal\Core\Ajax\AjaxResponse
   *   The ajax response with the new form.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  public static function generateToken(array &$form, FormStateInterface $form_state) {
    /** @var \Drupal\Core\Entity\Entity $entity */
    $entity = $form_state->getFormObject()->getEntity();
    /** @var \Drupal\access_unpublished\Entity\AccessToken $access_token */
    $access_token = \Drupal::entityTypeManager()->getStorage('access_token')->create(
      [
        'entity_type' => $entity->getEntityType()->id(),
        'entity_id' => $entity->id(),
        'expire' => $form_state->getValue('duration') > 0 ? \Drupal::time()->getRequestTime() + $form_state->getValue('duration') : -1,
      ]
    );
    $access_token->save();

    /** @var \Drupal\Core\Entity\EntityListBuilder $list_builder */
    $list_builder = \Drupal::service('entity_type.manager')->getHandler('access_token', 'entity_form_list_builder');

    $form = $list_builder->render($access_token->getHost());

    $response = new AjaxResponse();
    $response->addCommand(new ReplaceCommand('[data-drupal-selector="access-token-list"]', $form['table']));
    return $response;
  }

  /**
   * Get options for the duration form.
   *
   * @return array
   *   The form values.
   */
  public static function getDurationOptions() {
    $dateFormatter = \Drupal::service('date.formatter');
    $period = [86400, 172800, 345600, 604800, 1209600];
    $period = array_map([$dateFormatter, 'formatInterval'], array_combine($period, $period));
    $period[-1] = t('Unlimited');
    return $period;
  }

}

==> access_unpublished-8.x-1.9.zip: access_unpublished/src/Form/AccessUnpublishedForm.php <==
<?php

namespace Drupal\access_unpublished\Form;

use Drupal\access_unpublished\AccessUnpublished;
use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\ReplaceCommand;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Entity\EntityForm;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\workspaces\WorkspaceManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Alter the entity form to add access unpublished elements.
 */
class AccessUnpublishedForm implements ContainerInjectionInterface {

  use StringTranslationTrait;

  /**
   * Entity type manager service.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Access unpublished config.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $config;

  /**
   * Workspace manager service.
   *
   * @var \Drupal\workspaces\WorkspaceManagerInterface|null
   */
  protected $workspaceManager;

  /**
   * AccessUnpublishedForm constructor.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   Entity type manager service.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   Config factory service.
   * @param \Drupal\workspaces\WorkspaceManagerInterface|null $workspaceManager
   *   Workspace manager service.
   */
  public function __construct(EntityTypeManagerInterface $entityTypeManager, ConfigFactoryInterface $configFactory, ?WorkspaceManagerInterface $workspaceManager = NULL) {
    $this->entityTypeManager = $entityTypeManager;
    $this->config = $configFactory->get('access_unpublished.settings');
    $this->workspaceManager = $workspaceManager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager'),
      $container->get('config.factory'),
      $container->has('workspaces.manager') ? $container->get('workspaces.manager') : NULL
    );
  }

  /**
   * Alter the entity form to add access unpublished elements.
   */
  public function formAlter(&$form, FormStateInterface $form_state) {
    $form_object = $form_state->getFormObject();
    if (!$form_object instanceof EntityForm) {
      return;
    }

    $details_widget_base = [
      '#type' => 'details',
      '#title' => $this->t('Temporary unpublished access'),
      '#weight' => 35,
      '#attributes' => [
        'class' => ['access-unpublished-form'],
        'id' => 'edit-access-unpublished-settings',
      ],
      '#optional' => FALSE,
      '#group' => 'advanced',
    ];

    // Determines if the given form operation is add or edit. Prevents the
    // access unpublished form from being displayed on other random entity
    // forms, for example, the delete form.
    if (!in_array($form_object->getOperation(), ['edit', 'default'], TRUE)) {
      return;
    }

    /** @var \Drupal\Core\Entity\EntityInterface $entity */
    $entity = $form_object->getEntity();

    if (AccessUnpublished::applicableEntityType($entity->getEntityType()) && !$entity->isPublished() && !$entity->isNew()) {
      // Workspaces module is an alternative to access_unpublished. To reduce
      // confusion, this disables the access_unpublished widget on a form if
      // the user is in a workspace.
      if ($this->workspaceManager && $this->workspaceManager->hasActiveWorkspace()) {
        $form['access_unpublished_settings'] = $details_widget_base += [
          'info' => [
            '#markup' => $this->t(
              'You are currently in workspace %name. The temporary
            unpublished access module does not work well inside workspaces.',
              [
                '%name' => $this->workspaceManager->getActiveWorkspace()->label(),
              ]
            ),
          ],
        ];
        return;
      }

      /** @var \Drupal\Core\Entity\EntityListBuilder $list_builder */
      $list_builder = $this->entityTypeManager->getHandler('access_token', 'entity_form_list_builder');

      $form['access_unpublished_settings'] = $details_widget_base + $list_builder->render($entity);

      $form['access_unpublished_settings']['duration'] = [
        '#type' => 'select',
        '#title' => $this->t('Lifetime'),
        '#options' => static::getDurationOptions(),
        '#default_value' => $this->config->get('duration'),
        '#attributes' => [
          'id' => 'edit-duration',
        ],
      ];

      $form['access_unpublished_settings']['token_label'] = [
        '#type' => 'textfield',
        '#title' => $this->t('Token label'),
        '#default_value' => $this->config->get('label'),
        '#size' => 60,
        '#maxlength' => 128,
        '#attributes' => [
          'id' => 'edit-token-label',
        ],
      ];

      $form['access_unpublished_settings']['generate_token'] = [
        '#type' => 'button',
        '#value' => $this->t('Generate token'),
        '#ajax' => [
          'callback' => [__CLASS__, 'generateToken'],
        ],
        '#attributes' => [
          'id' => 'edit-generate-token',
        ],
      ];
    }
  }

  /**
   * Submit callback to generate a token.
   *
   * @param array $form
   *   Form array.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The form state.
   *
   * @return \Drupal\Core\Ajax\AjaxResponse
   *   The ajax response with the new form.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  public static function generateToken(array &$form, FormStateInterface $form_state) {
    /** @var \Drupal\Core\Entity\EntityInterface $entity */
    $entity = $form_state->getFormObject()->getEntity();
    /** @var \Drupal\access_unpublished\Entity\AccessToken $access_token */
    $access_token = \Drupal::entityTypeManager()->getStorage('access_token')->create(
      [
        'entity_type' => $entity->getEntityType()->id(),
        'entity_id' => $entity->id(),
        'label' => $form_state->getValue('token_label'),
        'expire' => $form_state->getValue('duration') > 0 ? \Drupal::time()->getRequestTime() + $form_state->getValue('duration') : -1,
      ]
    );
    $access_token->save();

    /** @var \Drupal\Core\Entity\EntityListBuilder $list_builder */
    $list_builder = \Drupal::service('entity_type.manager')->getHandler('access_token', 'entity_form_list_builder');

    $form = $list_builder->render($access_token->getHost());

    $response = new AjaxResponse();
    $response->addCommand(new ReplaceCommand('[data-drupal-selector="access-token-list"]', $form['table']));
    return $response;
  }

  /**
   * Get options for the duration form.
   *
   * @return array
   *   The form values.
   */
  public static function getDurationOptions() {
    $dateFormatter = \Drupal::service('date.formatter');
    $period = [86400, 172800, 345600, 604800, 1209600];
    $period = array_map([$dateFormatter, 'formatInterval'], array_combine($period, $period));
    $period[-1] = t('Unlimited');
    \Drupal::moduleHandler()->alter('access_unpublished_duration_options', $period);
    return $period;
  }

}
